@@ -18,10 +18,10 @@
 //! crates consistent.
 
 /// a Commitment
-pub type Commitment = sn_ringct::blstrs::G1Affine;
+pub type Commitment = bls_ringct::blstrs::G1Affine;
 
 /// a BlindingFactor
-pub type BlindingFactor = sn_ringct::blstrs::Scalar;
+pub type BlindingFactor = bls_ringct::blstrs::Scalar;
 
 /// A KeyImage can be thought of as a specific type
 /// of public key. blsttc::PublicKey is a newtype
